
///////////////////////////////////////////////////////////////////////////////
//
//   ROCKWELL SEMICONDUCTOR SYSTEMS - COMMERCIAL GPS BUSINESS
//
///////////////////////////////////////////////////////////////////////////////
//
//
//   MSG1330.C - Message 1330 Processing
// 
//
//   DESCRIPTION
//
//   Functions to decode, build, and display Zodiac 1330 messages.
//
//
//   REVISION HISTORY
//
//   $Log:   V:\Projects\Labmon\Source\Archives\MSG1330.C_V  $
//   
//      Rev 1.15   09 Nov 1998 10:48:08   phungh
//   labmon51: Fix file logging and missing
//   logged data bugs.  Changes made to the 
//   "Pause" variable ( 1 -> 0 ) to allow main
//   loop continue.  Move the "write to file"
//   code portion out of the interrupt handler
//   so that data is not missed because of time
//   spent too long in the interrupt handler
//   
//      Rev 1.3   Jul 09 1997 10:55:32   COLEJ
//    
//   
//      Rev 1.2   Feb 12 1997 16:05:48   COLEJ
//    
//   
//      Rev 1.1   Aug 13 1996 15:02:28   COLEJ
//    
//   
//      Rev 1.0   13 May 1996 14:53:18   GPSADMIN
//   Initial release to version control.
//
//
////////////////////////////////////////////////////////////////////////////////

#include <string.h>

#include "gentypes.h"
#include "gencons.h"
#include "ztypes.h"
#include "zcons.h"
#include "util.h"   

////////////////////////////////////////////////////////////////////////////////
//   
//   Decode a Zodiac 1330 message from the ZMsgBuf.
//
void Dec1330(tMSGBUF *ZMsgBuf, tMSG1330 *Msg)
{
   GetBit(&SPValidData.Port1       , ZMsgBuf, 7, 0);  // 1=valid    
   GetBit(&SPValidData.Port2       , ZMsgBuf, 7, 1);  // 1=valid
}                                      
                                     
////////////////////////////////////////////////////////////////////////////////
//   
//   Build a Zodiac 1330 message in the ZMsgBuf. 
//
void Bld1330(tMSGBUF *ZMsgBuf, tMSG1330 *Msg)
{
   // copy message into buffer
   memcpy(((tSHORT *) ZMsgBuf)+5, Msg, sizeof(*Msg));          

   // build the header in the buffer
   PutShort  (0x81FF               , ZMsgBuf, 1);     // message preamble
   PutShort  (1330                 , ZMsgBuf, 2);     // message number
   PutShort  (14                   , ZMsgBuf, 3);     // message length 
   PutShort  (ANREQ                , ZMsgBuf, 4);     // message ack/nack request
 
   PutBit(SPValidData.Port1        , ZMsgBuf, 7, 0);  // 1=valid    
   PutBit(SPValidData.Port2        , ZMsgBuf, 7, 1);  // 1=valid
}
